==> synergine-0.0.1.3.tar.gz: synergine-0.0.1.3/README.md <==
Synergine
=========

[![Travis-ci build passing](https://travis-ci.org/buxx/synergine.svg?branch=master)](https://travis-ci.org/buxx/synergine) - [![Coveralls coverage](https://coveralls.io/repos/buxx/synergine/badge.png?branch=master)](https://coveralls.io/r/buxx/synergine) - [![Scrutinizer Code Quality](https://scrutinizer-ci.com/g/buxx/synergine/badges/quality-score.png?b=master)](https://scrutinizer-ci.com/g/buxx/synergine/?branch=master) - [![Stories in Ready](https://badge.waffle.io/buxx/synergine.svg?label=ready&title=Ready)](http://waffle.io/buxx/synergine) 

Synergine is a [synergy](https://en.wikipedia.org/wiki/Synergy)/[stigmergy](https://en.wikipedia.org/wiki/Stigmergy) simulation framework. 

## Features

* Event based system
* Multiprocessing 
* Generic output (for display, stats, ...)
 
## Implementations

### Life game

[More about life game](http://en.wikipedia.org/wiki/Conway%27s_Game_of_Life)

[![Lifegame](https://raw.githubusercontent.com/buxx/synergine/master/doc/images/synergine_lifegame.gif)](https://raw.githubusercontent.com/buxx/synergine/master/doc/images/synergine_lifegame.gif) 

### Intelligine: Social bug simulation

Project github page [here](https://github.com/buxx/intelligine). 

[![Intelligine: egg management](https://raw.githubusercontent.com/buxx/intelligine/master/doc/images/intelligine_eggs_20150421.gif)](https://raw.githubusercontent.com/buxx/intelligine/master/doc/images/intelligine_eggs_20150421.gif) 

[![Intelligine: ressource exploration](https://raw.githubusercontent.com/buxx/intelligine/master/doc/images/intelligine_ressource_20150421_r.gif)](https://raw.githubusercontent.com/buxx/intelligine/master/doc/images/intelligine_ressource_20150421_r.gif)

==> synergine-0.0.1.7.tar.gz: synergine-0.0.1.7/README.md <==
Synergine
=========

[![Travis-ci build passing](https://travis-ci.org/buxx/synergine.svg?branch=master)](https://travis-ci.org/buxx/synergine) - [![Coveralls coverage](https://coveralls.io/repos/buxx/synergine/badge.png?branch=master)](https://coveralls.io/r/buxx/synergine) - [![Scrutinizer Code Quality](https://scrutinizer-ci.com/g/buxx/synergine/badges/quality-score.png?b=master)](https://scrutinizer-ci.com/g/buxx/synergine/?branch=master) - [![Stories in Ready](https://badge.waffle.io/buxx/synergine.svg?label=ready&title=Ready)](http://waffle.io/buxx/synergine) 

Synergine is a [synergy](https://en.wikipedia.org/wiki/Synergy)/[stigmergy](https://en.wikipedia.org/wiki/Stigmergy) simulation framework. 

## Documentation

You can found documentation [here](http://synergine.readthedocs.org/en/latest/)

## Features

* Event based system
* Multiprocessing 
* Generic output (for display, stats, ...)
 
## Implementations

### Life game

[More about life game](http://en.wikipedia.org/wiki/Conway%27s_Game_of_Life)

[![Lifegame](https://raw.githubusercontent.com/buxx/synergine/master/doc/images/synergine_lifegame_plot.gif)](https://raw.githubusercontent.com/buxx/synergine/master/doc/images/synergine_lifegame_plot.gif) 

### Intelligine: Social bug simulation

Project github page [here](https://github.com/buxx/intelligine). 

[![Intelligine: egg management](https://raw.githubusercontent.com/buxx/intelligine/master/doc/images/intelligine_eggs_20150421.gif)](https://raw.githubusercontent.com/buxx/intelligine/master/doc/images/intelligine_eggs_20150421.gif) 

[![Intelligine: ressource exploration](https://raw.githubusercontent.com/buxx/intelligine/master/doc/images/intelligine_ressource_20150421_r.gif)](https://raw.githubusercontent.com/buxx/intelligine/master/doc/images/intelligine_ressource_20150421_r.gif)
